function [BestBuffRank,RunTime,UpperRankOfBuffRank]=BestBuffRankFun(mInput,mOutput,iDMUo)
%inputs
%mInput: matrix of inputs, x_jm, row: DMU, column: input
%mOutput:matrix of outputs, x_jn, row: DMU, column: output
%jDMUo: a number, the DMU to be evaluated

%output
%BestRank: number, the best rank for DMUo
%RunTime: time in seconds, running time for computing DMUo's best ranking
%RankOfBuffRank: the upper rank of DMUo in J measures E_j(nu*,mu*)

problem_statement_BestBuffRank=...
             ['minimize', char(10),...
              '  bPOE(0, matrix_H)', char(10),...
              'Box: >= 0',char(10),...
              'Solver: van, init_point=0.1'];

[J,nInput]=size(mInput);
[J1,nOutput]=size(mOutput);
vInputDMUo=mInput(iDMUo,:);
vOutputDMUo=mOutput(iDMUo,:);

colnames={};
for i=1:nInput; colnames{i}=sprintf('nu_%g',i); end
for i=1:nOutput; colnames{nInput+i}=sprintf('mu_%g',i); end
mDMU=[mInput,-mOutput];

%H=mDMU-[vInputDMUo,-vOutputDMUo].*ones(J,1);
for i=1:J; H(i,:)=mDMU(i,:)-[vInputDMUo,-vOutputDMUo]; end

iargstruc_BuffRank(1) = matrix_pack('matrix_H',H,colnames);

[solution, outargstruc] = mpsg_solver(problem_statement_BestBuffRank, iargstruc_BuffRank);
fval= tbpsg_solution(solution, outargstruc,'objective');  
status=tbpsg_solution(solution, outargstruc,'solution_status');
vTime=tbpsg_solution(solution, outargstruc,'time');
RunTime=vTime(3);
BestBuffRank=J*fval;

vSoluBestBRank=get_optimalpoint(solution, iargstruc_BuffRank, outargstruc);
for iInput=1:nInput
    vOptNu(iInput,1)=vSoluBestBRank{iInput,2};
end
for iOutput=1:nOutput
    vOptMu(iOutput,1)=vSoluBestBRank{iOutput+nInput,2};
end
for jDMU=1:J
    vEffMeasure(jDMU,1)=mOutput(jDMU,:)*vOptMu-mInput(jDMU,:)*vOptNu;
end
UpperRankOfBuffRank=1+sum(vEffMeasure>vEffMeasure(iDMUo));